@@ -2,11 +2,12 @@ package Alien::Build::Plugin::PkgConfig::CommandLine;
 
 use strict;
 use warnings;
+use 5.008004;
 use Alien::Build::Plugin;
 use Carp ();
 
 # ABSTRACT: Probe system and determine library or tool properties using the pkg-config command line interface
-our $VERSION = '1.89'; # VERSION
+our $VERSION = '2.42'; # VERSION
 
 
 has '+pkg_name' => sub {
@@ -71,6 +72,9 @@ sub init
 {
   my($self, $meta) = @_;
 
+  my @probe;
+  my @gather;
+
   my $pkgconf = $self->bin_name;
 
   unless(defined $meta->prop->{env}->{PKG_CONFIG})
@@ -80,7 +84,7 @@ sub init
 
   my($pkg_name, @alt_names) = (ref $self->pkg_name) ? (@{ $self->pkg_name }) : ($self->pkg_name);
 
-  my @probe = map { [$pkgconf, '--exists', $_] } ($pkg_name, @alt_names);
+  push @probe, map { [$pkgconf, '--exists', $_] } ($pkg_name, @alt_names);
 
   if(defined $self->minimum_version)
   {
@@ -112,13 +116,20 @@ sub init
   unshift @probe, sub {
     my($build) = @_;
     $build->runtime_prop->{legacy}->{name} ||= $pkg_name;
+    $build->hook_prop->{probe_class} = __PACKAGE__;
+    $build->hook_prop->{probe_instance_id} = $self->instance_id;
   };
 
   $meta->register_hook(
     probe => \@probe
   );
 
-  my @gather = map { [ $pkgconf, '--exists', $_] } ($pkg_name, @alt_names);
+  push @gather, sub {
+    my($build) = @_;
+    die 'pkg-config command line probe does not match gather' if $build->hook_prop->{name} eq 'gather_system'
+    &&                                                        ($build->install_prop->{system_probe_instance_id} || '') ne $self->instance_id;
+  };
+  push @gather, map { [ $pkgconf, '--exists', $_] } ($pkg_name, @alt_names);
 
   foreach my $prop_name (qw( cflags libs version ))
   {
@@ -154,8 +165,12 @@ sub init
   if($meta->prop->{platform}->{system_type} eq 'windows-mingw')
   {
     @gather = map {
-      my($pkgconf, @rest) = @$_;
-      [$pkgconf, '--dont-define-prefix', @rest],
+      if(ref $_ eq 'ARRAY') {
+        my($pkgconf, @rest) = @$_;
+        [$pkgconf, '--dont-define-prefix', @rest],
+      } else {
+        $_
+      }
     } @gather;
   }
 
@@ -188,7 +203,7 @@ Alien::Build::Plugin::PkgConfig::CommandLine - Probe system and determine librar
 
 =head1 VERSION
 
-version 1.89
+version 2.42
 
 =head1 SYNOPSIS
 
@@ -199,7 +214,7 @@ version 1.89
 
 =head1 DESCRIPTION
 
-Note: in most case you will want to use L<Alien::Build::Plugin::Download::Negotiate>
+Note: in most case you will want to use L<Alien::Build::Plugin::PkgConfig::Negotiate>
 instead.  It picks the appropriate fetch plugin based on your platform and environment.
 In some cases you may need to use this plugin directly instead.
 
@@ -211,7 +226,10 @@ the best command line tools to accomplish this task.
 =head2 pkg_name
 
 The package name.  If this is a list reference then .pc files with all those package
-names must be present.
+names must be present.  The first name will be the primary and used by default once
+installed.  For the subsequent C<.pc> files you can use the
+L<Alien::Base alt method|Alien::Base/alt> to retrieve the alternate configurations
+once the L<Alien> is installed.
 
 =head2 atleast_version
 
@@ -283,7 +301,7 @@ Juan Julián Merelo Guervós (JJ)
 
 Joel Berger (JBERGER)
 
-Petr Pisar (ppisar)
+Petr Písař (ppisar)
 
 Lance Wicks (LANCEW)
 
@@ -299,9 +317,13 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
+nick nauwelaerts (INPHOBIA)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2019 by Graham Ollis.
+This software is copyright (c) 2011-2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
